function resize(options, UI) {

    options.w = parseInt(options.w) || 100;
    options.h = parseInt(options.h) || 100;

    var output;

    // This function is called on every draw.
    function draw(input, callback, progressObj) {

        progressObj.stop(true);
        progressObj.overrideFlag = true;

        var step = this;
        var imagejs = require('imagejs');

        function extraManipulation(pixels) {

            var bitmap = new imagejs.Bitmap({ width: pixels.shape[0], height: pixels.shape[1] });
            bitmap._data.data = pixels.data;


            var resized = bitmap.resize({
                width: options.w, height: options.h,
                algorithm: 'nearestNeighbor'
            });

            pixels.data = resized._data.data;
            pixels.shape = [options.w, options.h, 4];
            pixels.stride[1] = 4 * options.w;

            return pixels;
        }

        function output(image, datauri, mimetype) {

            // This output is accessible by Image Sequencer
            step.output = { src: datauri, format: mimetype };

        }

        // run PixelManipulation on first Image pixels
        return input.pixelManipulation({
            output: output,
            extraManipulation: extraManipulation,
            format: input.format,
            image: options.image,
            inBrowser: options.inBrowser,
            callback: callback
        });
    }

    return {
        options: options,
        draw: draw,
        output: output,
        UI: UI
    };
};

var info = {
    "name": "Exporter Overlay",
    "description": "Overlays an Image over another at a given position(x,y) in pixels or in %",
    "inputs": {
        "w": {
            "type": "integer",
            "desc": "Final Width of the image",
            "default": 100
        },
        "h": {
            "type": "integer",
            "desc": "Final Height of the Image",
            "default": 100
        }
    }
}

module.exports = {
    func: resize,
    info: info
}